@@ -527,13 +527,13 @@ class PintBlueprint(BaseRest, Blueprint):
         """Will forward all arguments and keyword arguments to Blueprints"""
         super().__init__(*args, **kwargs)
 
-    def register(self, app: Pint, options: dict, first_registration: bool = False) -> None:
+    def register(self, app: Pint, options: dict, *args: object, **kwargs: object) -> None:
         """override the base :meth:`~quart.Blueprint.register` method to add the resources to the app registering
         this blueprint, then call the parent register method
         """
         prefix = options.get('url_prefix', '') or self.url_prefix or ''
         app.resources.extend([(res, f'{prefix}{path}', methods) for res, path, methods in self._resources])
-        super().register(app, options, first_registration)
+        super().register(app, options, *args, **kwargs)
 
 class OpenApiView(Resource):
     """The :class:`Resource` used for the '/openapi.json' route
